Function sozu_client::config::canonicalize_command_socket
source · pub fn canonicalize_command_socket(
path: &PathBuf,
config: &Config
) -> Result<PathBuf, Error>Expand description
Canonicalize command socket. Take the path of the configuration and the configuration to retrieve the canonical path of the command socket.